@@ -10,7 +10,11 @@ class FileField(_FileField):
     def process_formdata(self, valuelist):
         if len(valuelist) != 1:
             raise ValueError(self.gettext('Only accept one file.'))
-        self.data = valuelist[0]
+        # valuelist will be [b''] if no file uploaded, so set data to None
+        if valuelist == [b'']:
+            self.data = None
+        else:
+            self.data = valuelist[0]
 
 class MultiFilesField(_FileField):
     '''
@@ -19,4 +23,8 @@ class MultiFilesField(_FileField):
     widget = _widgets.MultiFilesInput()
 
     def process_formdata(self, valuelist):
-        self.data = valuelist
+        # valuelist will be [b''] if no files uploaded, so set data to None
+        if valuelist == [b'']:
+            self.data = None
+        else:
+            self.data = valuelist
